"""This module contains boilerplate logging helpers."""
import logging.config

SANE_BASE_LOGGING_CONFIG = {
    "logging": {
        "version": 1,
        "disable_existing_loggers": False,
        "formatters": {
            "simple": {"format": "%(asctime)s: %(message)s"},
            "verbose": {
                "format": "%(asctime)s [%(levelname)s] %(module)s %(message)s"
            },
        },
        "handlers": {
            "console": {
                "class": "logging.StreamHandler",
                "level": "DEBUG",
                "formatter": "simple",
                "stream": "ext://sys.stdout",
            }
        },
        "root": {"level": "DEBUG", "handlers": ["console"]},
    }
}


def setup_logging(self, name="root", cfg=None):
    """Create a logger.

    :param name:
        The name of the logger, defaults to 'root'.
    :param cfg:
        The configuration ``dict``, defaults to ``SANE_BASE_LOGGING_CONFIG``.
    :return:
        A logger with the specified name.
    """
    logging.config.dictConfig(cfg or SANE_BASE_LOGGING_CONFIG)
    return logging.getLogger(name)



"""This module contains boilerplate hashlib helpers."""
import hashlib

__all__ = ["md5", "sha1"]


def md5(s):
    """Compute the MD5 of a given string."""
    return hashlib.md5(s.encode("utf-8")).hexdigest()


def sha1(s):
    """Compute the SHA1 of a given string."""
    return hashlib.sha1(s.encode("utf-8")).hexdigest()



# flake8: noqa
__title__ = "yakutils"
__version__ = "1.1.5"
__author__ = "Nick Ficano"
__license__ = "MIT License"
__copyright__ = "Copyright 2020 Nick Ficano"

from ._csv import iter_csv
from ._csv import read_csv
from ._json import iter_json
from ._json import read_json
from ._json import JSONEncoder
from ._logging import SANE_BASE_LOGGING_CONFIG
from ._logging import setup_logging
from ._datetime import to_timezone
from ._datetime import (
    iso8601_to_datetime,
    datetime_to_iso8601,
    date_to_iso8601,
    datetime_to_unixtimestamp,
)
from ._random import random_string
from ._hashlib import md5
from ._hashlib import sha1
from ._urllib import update_qs



"""This module contains setup instructions for yakutils."""
import codecs
import os
import sys
from shutil import rmtree

from setuptools import Command
from setuptools import setup

THIS_DIR = os.path.abspath(os.path.dirname(__file__))
README = os.path.join(THIS_DIR, "README.md")

with codecs.open(README, encoding="utf-8") as fh:
    long_description = "\n" + fh.read()


class UploadCommand(Command):
    """Support setup.py publish."""

    description = "Build and publish the package."
    user_options = []

    @staticmethod
    def status(s):
        """Print in bold."""
        print(f"\033[1m{s}\033[0m")

    def initialize_options(self):
        """Initialize options."""
        pass

    def finalize_options(self):
        """Finialize options."""
        pass

    def run(self):
        """Upload release to Pypi."""
        try:
            self.status("Removing previous builds ...")
            rmtree(os.path.join(THIS_DIR, "dist"))
        except Exception:
            pass
        self.status("Building Source distribution ...")
        os.system(f"{sys.executable} setup.py sdist")
        self.status("Uploading the package to PyPI via Twine ...")
        os.system("twine upload dist/*")
        sys.exit()


setup(
    name="yakutils",
    version="1.1.5",
    author="Nick Ficano",
    author_email="nficano@gmail.com",
    packages=["yakutils"],
    url="https://github.com/nficano/yakutils",
    license="MIT",
    package_data={"": ["LICENSE"]},
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: Implementation :: CPython",
        "Programming Language :: Python :: Implementation :: PyPy",
    ],
    description="A really lazy package",
    include_package_data=True,
    long_description_content_type="text/markdown",
    long_description=long_description,
    zip_safe=True,
    cmdclass={"upload": UploadCommand},
)



"""This module contains boilerplate csv helpers."""
import csv


def read_csv(filename):
    """Read a CSV file.

    **Example**:

    >>> read_csv('/path/to/data.csv')
    [{ 'name': 'foo' }]

    :param filename:
        Path to CSV file.
    :return:
        A Python representation of the CSV document.
    """
    with open(filename) as fh:
        field_names = (
            fh.readline().replace('"', "").replace("\n", "").split(",")
        )
        dict_reader = csv.DictReader(fh, fieldnames=field_names)
        return list(dict(row) for row in dict_reader)


def iter_csv(filename):
    """Iterate a CSV file.

    **Example**:

    >>> for item in iter_csv('/path/to/data.csv'):
    ...     print(item)
    [{ 'name': 'foo' }]

    :param filename:
        Path to CSV file.
    :yield:
        A Python ``dict`` representation of a CSV row.
    """
    with open(filename) as fh:
        field_names = (
            fh.readline().replace('"', "").replace("\n", "").split(",")
        )
        dict_reader = csv.DictReader(fh, fieldnames=field_names)
        for item in list(dict(row) for row in dict_reader):
            yield item
